"""Constant like things"""
DEFAULT_DB = "/etc/pihole/gravity.db"

BLACKLIST = 1
WHITELIST = 2

# item types
URL = 1
REGEX = 2


FILE = 100
PASTE = 101

# BLACKLIST SOURCES
B_FIREBOG_NOCROSS = 1
B_FIREBOG_TICKED = 2
B_FIREBOG_ALL = 3

# WHITELIST SOURCES
W_ANUDEEP_WHITE = 1
W_ANUDEEP_REFERRAL = 2
W_ANUDEEP_OPTIONAL = 3
